import java.io.BufferedReader;
import java.io.Console;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;

import org.htmlparser.Node;
import org.htmlparser.NodeFilter;
import org.htmlparser.Parser;
import org.htmlparser.filters.AndFilter;
import org.htmlparser.filters.HasAttributeFilter;
import org.htmlparser.filters.NodeClassFilter;
import org.htmlparser.filters.NotFilter;
import org.htmlparser.filters.OrFilter;
import org.htmlparser.filters.RegexFilter;
import org.htmlparser.filters.StringFilter;
import org.htmlparser.filters.TagNameFilter;
import org.htmlparser.nodes.RemarkNode;
import org.htmlparser.tags.AppletTag;
import org.htmlparser.tags.BodyTag;
import org.htmlparser.tags.FormTag;
import org.htmlparser.tags.InputTag;
import org.htmlparser.tags.JspTag;
import org.htmlparser.tags.LinkTag;
import org.htmlparser.tags.ProcessingInstructionTag;
import org.htmlparser.tags.ScriptTag;
import org.htmlparser.tags.SelectTag;
import org.htmlparser.tags.StyleTag;
import org.htmlparser.tags.TextareaTag;
import org.htmlparser.util.NodeList;
import org.htmlparser.util.ParserException;


public class HtmlParser {
	
	// List of all nodes in the parser
	private NodeList allNodes;
	
	private NotFilter notFilter;
	// Parser
	private Parser parser;
	
	private static NodeClassFilter nodeClassFilter[] = {
			new NodeClassFilter(AppletTag.class), //Applet tag
			new NodeClassFilter(FormTag.class), //Form Tag
			new NodeClassFilter(InputTag.class), //Input Tag
			new NodeClassFilter(JspTag.class), // Jsp class
			new NodeClassFilter(ScriptTag.class), // Script Tag
			new NodeClassFilter(SelectTag.class), // Select Tag
			new NodeClassFilter(StyleTag.class), // css
			new NodeClassFilter(TextareaTag.class), //Textarea tag
			new NodeClassFilter(ProcessingInstructionTag.class), // xml
			new NodeClassFilter(RemarkNode.class)
	};
		
	/***
	 * Constructor
	 * @param file
	 */
	public HtmlParser(String file) throws ParserException {
		parser = new Parser(file);
		allNodes = parser.parse(null);
	}
	
	
	private void Filter() throws ParserException {
		NotFilter notFilter = new NotFilter(new OrFilter(nodeClassFilter));
		//allNodes = parser.extractAllNodesThatMatch(andFilter);
		allNodes.keepAllNodesThatMatch(notFilter, true);	
		
		notFilter = new NotFilter(new HasAttributeFilter("rel", "stylesheet"));
		allNodes.keepAllNodesThatMatch(notFilter, true);
		
	}	
	
	/***
	 * Changes all <a href ...> to <a href = "#">
	 */
	private void RemoveLink() {
		for(int i = 0; i < allNodes.size(); i++)
			RemoveLink(allNodes.elementAt(i));
	}
	
	private void RemoveLink(Node node) {
		if(node.getClass().equals(LinkTag.class)) {
			LinkTag linkTag = (LinkTag) node;
			linkTag.setLink("#");
		}
		else {
			NodeList children = node.getChildren();
			if(children != null) {
				for(int i = 0; i < children.size(); i++) {
					Node child = children.elementAt(i);
					RemoveLink(child);
				}
			}
			
		}		
			
	}
	
	/***
	 * Main: Takes the file name as a command line argument and prunes the html file
	 * @param args
	 */
	public static void main(String args[]) {
		StringBuffer input = new StringBuffer("");
		String line = "";
		
		try {
			BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
			while((line = br.readLine()) != null)
				input.append(line + "\n");
			HtmlParser htmlParser = new HtmlParser(input.toString());
						
			//Filter
			htmlParser.Filter();
			
			// Remove Link
			htmlParser.RemoveLink();
			
			System.out.println(htmlParser.allNodes.toHtml());
		}
		
		catch (ParserException e) {
			// Exception
			System.err.println("Html Parser threw ParseException while parsing the html file...file might not be in correct format");
			System.out.println();
		}	
		
		catch (IOException e) {
			// TODO: handle exception
			System.err.println("Could not read the file (could be too big)");
			System.out.println();
		}
	}
}
